@@ -198,18 +198,17 @@ class NHCController:
         """Handle an energy event."""
         _LOGGER.debug(f"energy: {self._energy}")
         _LOGGER.debug(f"handle_energy_event: {event}")
-        # in watts?
-        # self.update_state(event["channel"], event["v"])
-    
-        # await self.async_dispatch_update(event["channel"], event["v"])
+        id = f"energy-{event['channel']}"
+        self.update_state(id, event["v"])
+        await self.async_dispatch_update(id, event["v"])
+
     async def handle_thermostat_event(self, event: dict[str, Any]) -> None:
         """Handle an energy event."""
         _LOGGER.debug(f"thermostat: {self._thermostats}")
         _LOGGER.debug(f"handle_thermostat_event: {event}")
-        # in watts?
-        # self.update_state(event["channel"], event["v"])
-
-        # await self.async_dispatch_update(event["channel"], event["v"])
+        id = f"thermostat-{event['id']}"
+        self.update_state(id, event)
+        await self.async_dispatch_update(id, event)
 
     async def _listen(self) -> None:
         """
@@ -230,12 +229,12 @@ class NHCController:
                 if "event" in message and message["event"] != "startevents":
                     # The controller also sends energy and thermostat events, so we make sure we handle those separately
                     _LOGGER.debug(f"message: {message}")
-                    for data in message["data"]:
-                        if message["event"] == "getlive":
-                            await self.handle_energy_event(data)
-                        elif message["event"] == "listthermostat":
-                            await self.handle_thermostat_event(data)
-                        else:
+                    if message["event"] == "getlive":
+                        await self.handle_energy_event(message["data"])
+                    elif message["event"] == "thermostat":
+                        await self.handle_thermostat_event(message["data"])
+                    else:
+                        for data in message["data"]:
                             await self.handle_event(data)
         finally:
             self._writer.close()
